@@ -57,7 +57,8 @@ class BalconyServiceSummarizer(BaseBalconyApp,
             nonlocal self
             resource_node_names = [r.get('name') for r in data.get('resource_nodes')]
             for ky in kayan_yazi(resource_node_names):
-                layout = Layout(Panel(ky), name="main")
+                str_ky = '\n'.join(ky)
+                layout = Layout(Panel(str_ky), name="main")
                 yield layout
 
 
